@@ -19,7 +19,7 @@ Copyright 2021      Christopher R. Nelson <christopher.nelson@languidnights.com>
 Copyright 2021-2023 Guilherme Janczak <guilherme.janczak@yandex.com>
 Copyright 2021      IFo Hancroft <contact@ifohancroft.com>
 Copyright 2021      Peter Wu <peterwu@hotmail.com>
-Copyright 2022-2023 NRK <nrk@disroot.org>
+Copyright 2022-2024 NRK <nrk@disroot.org>
 Copyright 2022      Zev Weiss <zev@bewilderbeest.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -271,7 +271,8 @@ static void scrotSaveImage(const char *filename)
     Imlib_Load_Error imErr;
     imlib_save_image_with_error_return(filename, &imErr);
     if (imErr) {
-        const char *colon = "", *errmsg = "", imlibPrefix[] = "Imlib2: ";
+        const char *colon = "", *errmsg = "";  // NOLINT(*DeadStores)
+        const char imlibPrefix[] = "Imlib2: ";
 #if defined(IMLIB2_VERSION)
 #if IMLIB2_VERSION >= IMLIB2_VERSION_(1, 10, 0)
         colon = ": ";
@@ -297,9 +298,9 @@ size_t scrotHaveFileExtension(const char *filename, char **ext)
     return strlen(*ext);
 }
 
-Imlib_Image scrotGrabRectAndPointer(int x, int y, int w, int h)
+Imlib_Image scrotGrabRectAndPointer(int x, int y, int w, int h, bool isGrabbed)
 {
-    Imlib_Image im = imlib_create_image_from_drawable(0, x, y, w, h, 1);
+    Imlib_Image im = imlib_create_image_from_drawable(0, x, y, w, h, !isGrabbed);
     if (!im)
         errx(EXIT_FAILURE, "failed to grab image");
     if (opt.pointer)
@@ -315,7 +316,7 @@ static Imlib_Image scrotGrabWindowById(Window const window)
     if (!scrotGetGeometry(window, &rx, &ry, &rw, &rh))
         return NULL;
     scrotNiceClip(&rx, &ry, &rw, &rh);
-    im = scrotGrabRectAndPointer(rx, ry, rw, rh);
+    im = scrotGrabRectAndPointer(rx, ry, rw, rh, false);
     clientWindow = window;
     return im;
 }
@@ -333,7 +334,7 @@ static Imlib_Image scrotGrabAutoselect(void)
     int rx = opt.autoselectX, ry = opt.autoselectY, rw = opt.autoselectW,
         rh = opt.autoselectH;
     scrotNiceClip(&rx, &ry, &rw, &rh);
-    return scrotGrabRectAndPointer(rx, ry, rw, rh);
+    return scrotGrabRectAndPointer(rx, ry, rw, rh, false);
 }
 
 void scrotDoDelay(void)
@@ -625,7 +626,7 @@ static Imlib_Image scrotGrabShot(void)
 {
     if (!opt.silent)
         XBell(disp, 0);
-    return scrotGrabRectAndPointer(0, 0, scr->width, scr->height);
+    return scrotGrabRectAndPointer(0, 0, scr->width, scr->height, false);
 }
 
 static void scrotExecApp(Imlib_Image image, struct tm *tm, char *filenameIM,
@@ -984,7 +985,7 @@ static Imlib_Image scrotGrabShotMonitor(void)
     XFree(screens);
 
     scrotNiceClip(&x, &y, &w, &h);
-    return scrotGrabRectAndPointer(x, y, w, h);
+    return scrotGrabRectAndPointer(x, y, w, h, false);
 }
 
 static Imlib_Image stalkImageConcat(
