@@ -4,7 +4,7 @@ Copyright 2020-2021 Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2021-2023 Guilherme Janczak <guilherme.janczak@yandex.com>
 Copyright 2021      Martin C <martincation@protonmail.com>
 Copyright 2021      Peter Wu <peterwu@hotmail.com>
-Copyright 2023      NRK <nrk@disroot.org>
+Copyright 2023-2025 NRK <nrk@disroot.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -90,6 +90,7 @@ struct SelectionClassic {
 };
 struct SelectionEdge {
     Window wndDraw;
+    bool isMapped;
 };
 
 struct Selection {
@@ -108,7 +109,7 @@ struct Selection {
 extern struct Selection selection;
 
 void selectionCalculateRect(int, int, int, int);
-void scrotSelectionGetLineColor(XColor *);
+XColor scrotSelectionGetLineColor(void);
 Imlib_Image scrotSelectionSelectMode(void);
 
 #endif /* !defined(H_SCROT_SELECTION) */
