@@ -3,7 +3,7 @@
 Copyright 2020-2021 Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2021-2023 Guilherme Janczak <guilherme.janczak@yandex.com>
 Copyright 2021      Peter Wu <peterwu@hotmail.com>
-Copyright 2023      NRK <nrk@disroot.org>
+Copyright 2023-2025 NRK <nrk@disroot.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -57,8 +57,7 @@ void selectionClassicCreate(void)
     pc->gcValues.plane_mask = pc->gcValues.background ^ pc->gcValues.foreground;
     pc->gcValues.subwindow_mode = IncludeInferiors;
 
-    XColor color;
-    scrotSelectionGetLineColor(&color);
+    XColor color = scrotSelectionGetLineColor();
 
     if (color.pixel != blackColor)
         pc->gcValues.foreground = color.pixel;
@@ -71,9 +70,6 @@ void selectionClassicCreate(void)
 
     XSetLineAttributes(disp, pc->gc, opt.lineWidth, opt.lineStyle, CapRound,
         JoinRound);
-
-    if (opt.freeze)
-        XGrabServer(disp);
 }
 
 void selectionClassicDraw(void)
@@ -100,11 +96,6 @@ void selectionClassicDestroy(void)
     const struct Selection *const sel = &selection;
     const struct SelectionClassic *pc = &sel->classic;
 
-    if (opt.freeze)
-        XUngrabServer(disp);
-
     if (pc->gc)
         XFreeGC(disp, pc->gc);
-
-    XFlush(disp);
 }
