@@ -3,7 +3,7 @@
 Copyright 2020-2021 Daniel T. Borelli <danieltborelli@gmail.com>
 Copyright 2021-2023 Guilherme Janczak <guilherme.janczak@yandex.com>
 Copyright 2021      Peter Wu <peterwu@hotmail.com>
-Copyright 2023-2024 NRK <nrk@disroot.org>
+Copyright 2023-2025 NRK <nrk@disroot.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -50,8 +50,7 @@ void selectionEdgeCreate(void)
 {
     struct SelectionEdge *const pe = &selection.edge;
 
-    XColor color;
-    scrotSelectionGetLineColor(&color);
+    XColor color = scrotSelectionGetLineColor();
 
     XSetWindowAttributes attr;
     attr.background_pixel = color.pixel;
@@ -60,6 +59,7 @@ void selectionEdgeCreate(void)
     pe->wndDraw = XCreateWindow(disp, root, 0, 0, WidthOfScreen(scr),
         HeightOfScreen(scr), 0, CopyFromParent, InputOutput, CopyFromParent,
         CWOverrideRedirect | CWBackPixel, &attr);
+    pe->isMapped = false;
 
     unsigned long opacity = opt.lineOpacity * (0xFFFFFFFFu / 255);
 
@@ -79,8 +79,8 @@ void selectionEdgeCreate(void)
 
 void selectionEdgeDraw(void)
 {
-    const struct Selection *const sel = &selection;
-    const struct SelectionEdge *const pe = &sel->edge;
+    struct Selection *const sel = &selection;
+    struct SelectionEdge *const pe = &sel->edge;
 
     XRectangle rects[4] = {
         { sel->rect.x, sel->rect.y, opt.lineWidth, sel->rect.h }, // left
@@ -95,6 +95,7 @@ void selectionEdgeDraw(void)
     XShapeCombineRectangles(disp, pe->wndDraw, ShapeBounding, 0, 0, rects, 4,
         ShapeSet, 0);
     XMapWindow(disp, pe->wndDraw);
+    pe->isMapped = true;
 }
 
 void selectionEdgeMotionDraw(int x0, int y0, int x1, int y1)
@@ -118,13 +119,13 @@ void selectionEdgeDestroy(void)
     if (pe->wndDraw != None) {
         XSelectInput(disp, pe->wndDraw, StructureNotifyMask);
         XDestroyWindow(disp, pe->wndDraw);
-        bool is_unmapped = false, is_destroyed = false;
-        for (XEvent ev; !(is_unmapped && is_destroyed);) {
+        bool isUnmapped = !pe->isMapped, isDestroyed = false;
+        for (XEvent ev; !(isUnmapped && isDestroyed);) {
             XNextEvent(disp, &ev);
             if (ev.type == DestroyNotify && ev.xdestroywindow.window == pe->wndDraw)
-                is_destroyed = true;
+                isDestroyed = true;
             if (ev.type == UnmapNotify && ev.xunmap.window == pe->wndDraw)
-                is_unmapped = true;
+                isUnmapped = true;
         }
     }
 }
